@@ -63,7 +63,7 @@ def test_main_sys_argv(tomcat_manager_server, capsys, monkeypatch):
     assert exit_code == 0
     assert "Path" in out[0]
     assert "Sessions" in out[0]
-    assert "--connected to" in err[0]
+    assert "connected to" in err[0]
 
 
 def test_main_user_password_url_command(tomcat_manager_server, capsys):
@@ -79,7 +79,7 @@ def test_main_user_password_url_command(tomcat_manager_server, capsys):
     assert exit_code == 0
     assert "Path" in out[0]
     assert "Sessions" in out[0]
-    assert "--connected to" in err[0]
+    assert "connected to" in err[0]
 
 
 def test_main_quiet(tomcat_manager_server, capsys):
@@ -166,7 +166,7 @@ def test_main_stdin(tomcat_manager_server, capsys):
     assert exit_code == 0
     assert "Path" in out[0]
     assert "Sessions" in out[0]
-    assert "--connected to" in err[0]
+    assert "connected to" in err[0]
 
 
 def test_main_echo(tomcat_manager_server, capsys):
@@ -190,7 +190,7 @@ def test_main_echo(tomcat_manager_server, capsys):
     assert " list" in out[0]
     assert "Path" in out[1]
     assert "Sessions" in out[1]
-    assert "--connected to" in err[0]
+    assert "connected to" in err[0]
 
 
 def test_main_status_to_stdout(tomcat_manager_server, capsys):
@@ -204,8 +204,8 @@ def test_main_status_to_stdout(tomcat_manager_server, capsys):
     out, _ = capsys.readouterr()
     out = out.splitlines()
     assert exit_code == 0
-    assert "--connected to" in out[0]
-    assert "--tomcat version" in out[1]
+    assert "connected to" in out[0]
+    assert "tomcat version" in out[1]
     assert "Path" in out[2]
     assert "Sessions" in out[2]
 
